@@ -20,7 +20,7 @@
 #
 
 import logging
-from typing import TYPE_CHECKING, Any, List, Optional, Tuple
+from typing import TYPE_CHECKING, Any, Optional
 
 import attr
 import msgpack
@@ -67,14 +67,14 @@ class RoomListHandler:
         self.hs = hs
         self.enable_room_list_search = hs.config.roomdirectory.enable_room_list_search
         self.response_cache: ResponseCache[
-            Tuple[Optional[int], Optional[str], Optional[ThirdPartyInstanceID]]
+            tuple[Optional[int], Optional[str], Optional[ThirdPartyInstanceID]]
         ] = ResponseCache(
             clock=hs.get_clock(),
             name="room_list",
             server_name=self.server_name,
         )
         self.remote_response_cache: ResponseCache[
-            Tuple[str, Optional[int], Optional[str], bool, Optional[str]]
+            tuple[str, Optional[int], Optional[str], bool, Optional[str]]
         ] = ResponseCache(
             clock=hs.get_clock(),
             name="remote_room_list",
@@ -175,7 +175,7 @@ class RoomListHandler:
         if since_token:
             batch_token = RoomListNextBatch.from_token(since_token)
 
-            bounds: Optional[Tuple[int, str]] = (
+            bounds: Optional[tuple[int, str]] = (
                 batch_token.last_joined_members,
                 batch_token.last_room_id,
             )
@@ -226,7 +226,7 @@ class RoomListHandler:
             return {k: v for k, v in entry.items() if v is not None}
 
         # Build a list of up to `limit` entries.
-        room_entries: List[JsonDict] = []
+        room_entries: list[JsonDict] = []
         rooms_iterator = results if forwards else reversed(results)
 
         # Track the first and last 'considered' rooms so that we can provide correct
