@@ -15,7 +15,7 @@
 import itertools
 import logging
 from itertools import chain
-from typing import TYPE_CHECKING, AbstractSet, Dict, List, Mapping, Optional, Set, Tuple
+from typing import TYPE_CHECKING, AbstractSet, Mapping, Optional
 
 from prometheus_client import Histogram
 from typing_extensions import assert_never
@@ -116,7 +116,7 @@ class SlidingSyncHandler:
         sync_config: SlidingSyncConfig,
         from_token: Optional[SlidingSyncStreamToken] = None,
         timeout_ms: int = 0,
-    ) -> Tuple[SlidingSyncResult, bool]:
+    ) -> tuple[SlidingSyncResult, bool]:
         """
         Get the sync for a client if we have new data for it now. Otherwise
         wait for new data to arrive on the server. If the timeout expires, then
@@ -262,7 +262,7 @@ class SlidingSyncHandler:
         relevant_rooms_to_send_map = interested_rooms.relevant_rooms_to_send_map
 
         # Fetch room data
-        rooms: Dict[str, SlidingSyncResult.RoomResult] = {}
+        rooms: dict[str, SlidingSyncResult.RoomResult] = {}
 
         new_connection_state = previous_connection_state.get_mutable()
 
@@ -490,7 +490,7 @@ class SlidingSyncHandler:
         room_membership_for_user_at_to_token: RoomsForUserType,
         from_token: RoomStreamToken,
         to_token: RoomStreamToken,
-    ) -> List[StateDelta]:
+    ) -> list[StateDelta]:
         """
         Get the state deltas between two tokens taking into account the user's
         membership. If the user is LEAVE/BAN, we will only get the state deltas up to
@@ -677,8 +677,8 @@ class SlidingSyncHandler:
         # membership. Currently, we have to make all of these optional because
         # `invite`/`knock` rooms only have `stripped_state`. See
         # https://github.com/matrix-org/matrix-spec-proposals/pull/3575#discussion_r1653045932
-        timeline_events: List[EventBase] = []
-        bundled_aggregations: Optional[Dict[str, BundledAggregations]] = None
+        timeline_events: list[EventBase] = []
+        bundled_aggregations: Optional[dict[str, BundledAggregations]] = None
         limited: Optional[bool] = None
         prev_batch_token: Optional[StreamToken] = None
         num_live: Optional[int] = None
@@ -813,7 +813,7 @@ class SlidingSyncHandler:
 
         # Figure out any stripped state events for invite/knocks. This allows the
         # potential joiner to identify the room.
-        stripped_state: List[JsonDict] = []
+        stripped_state: list[JsonDict] = []
         if room_membership_for_user_at_to_token.membership in (
             Membership.INVITE,
             Membership.KNOCK,
@@ -924,7 +924,7 @@ class SlidingSyncHandler:
         # see https://github.com/matrix-org/matrix-spec/issues/380. This means that
         # clients won't be able to calculate the room name when necessary and just a
         # pitfall we have to deal with until that spec issue is resolved.
-        hero_user_ids: List[str] = []
+        hero_user_ids: list[str] = []
         # TODO: Should we also check for `EventTypes.CanonicalAlias`
         # (`m.room.canonical_alias`) as a fallback for the room name? see
         # https://github.com/matrix-org/matrix-spec-proposals/pull/3575#discussion_r1671260153
@@ -1036,7 +1036,7 @@ class SlidingSyncHandler:
                 )
                 required_state_filter = StateFilter.all()
             else:
-                required_state_types: List[Tuple[str, Optional[str]]] = []
+                required_state_types: list[tuple[str, Optional[str]]] = []
                 num_wild_state_keys = 0
                 lazy_load_room_members = False
                 num_others = 0
@@ -1057,7 +1057,7 @@ class SlidingSyncHandler:
                             lazy_load_room_members = True
 
                             # Everyone in the timeline is relevant
-                            timeline_membership: Set[str] = set()
+                            timeline_membership: set[str] = set()
                             if timeline_events is not None:
                                 for timeline_event in timeline_events:
                                     # Anyone who sent a message is relevant
@@ -1219,7 +1219,7 @@ class SlidingSyncHandler:
             room_avatar = avatar_event.content.get("url")
 
         # Assemble heroes: extract the info from the state we just fetched
-        heroes: List[SlidingSyncResult.RoomResult.StrippedHero] = []
+        heroes: list[SlidingSyncResult.RoomResult.StrippedHero] = []
         for hero_user_id in hero_user_ids:
             member_event = room_state.get((EventTypes.Member, hero_user_id))
             if member_event is not None:
@@ -1374,7 +1374,7 @@ class SlidingSyncHandler:
         self,
         room_id: str,
         to_token: StreamToken,
-        timeline: List[EventBase],
+        timeline: list[EventBase],
         check_outside_timeline: bool,
     ) -> Optional[int]:
         """Get a bump stamp for the room, if we have a bump event and it has
@@ -1479,7 +1479,7 @@ def _required_state_changes(
     prev_required_state_map: Mapping[str, AbstractSet[str]],
     request_required_state_map: Mapping[str, AbstractSet[str]],
     state_deltas: StateMap[str],
-) -> Tuple[Optional[Mapping[str, AbstractSet[str]]], StateFilter]:
+) -> tuple[Optional[Mapping[str, AbstractSet[str]]], StateFilter]:
     """Calculates the changes between the required state room config from the
     previous requests compared with the current request.
 
@@ -1524,15 +1524,15 @@ def _required_state_changes(
 
     # Contains updates to the required state map compared with the previous room
     # config. This has the same format as `RoomSyncConfig.required_state`
-    changes: Dict[str, AbstractSet[str]] = {}
+    changes: dict[str, AbstractSet[str]] = {}
 
     # The set of types/state keys that we need to fetch and return to the
     # client. Passed to `StateFilter.from_types(...)`
-    added: List[Tuple[str, Optional[str]]] = []
+    added: list[tuple[str, Optional[str]]] = []
 
     # Convert the list of state deltas to map from type to state_keys that have
     # changed.
-    changed_types_to_state_keys: Dict[str, Set[str]] = {}
+    changed_types_to_state_keys: dict[str, set[str]] = {}
     for event_type, state_key in state_deltas:
         changed_types_to_state_keys.setdefault(event_type, set()).add(state_key)
 
