@@ -21,7 +21,7 @@
 import logging
 from contextlib import AsyncExitStack
 from types import TracebackType
-from typing import TYPE_CHECKING, Collection, Optional, Set, Tuple, Type
+from typing import TYPE_CHECKING, Collection, Optional
 from weakref import WeakValueDictionary
 
 from twisted.internet import defer
@@ -82,7 +82,7 @@ class LockStore(SQLBaseStore):
 
         # A map from `(lock_name, lock_key)` to lock that we think we
         # currently hold.
-        self._live_lock_tokens: WeakValueDictionary[Tuple[str, str], Lock] = (
+        self._live_lock_tokens: WeakValueDictionary[tuple[str, str], Lock] = (
             WeakValueDictionary()
         )
 
@@ -91,7 +91,7 @@ class LockStore(SQLBaseStore):
         # multiple read locks at a time but only one write lock (no mixing read
         # and write locks at the same time).
         self._live_read_write_lock_tokens: WeakValueDictionary[
-            Tuple[str, str, str], Lock
+            tuple[str, str, str], Lock
         ] = WeakValueDictionary()
 
         # When we shut down we want to remove the locks. Technically this can
@@ -104,7 +104,7 @@ class LockStore(SQLBaseStore):
             shutdown_func=self._on_shutdown,
         )
 
-        self._acquiring_locks: Set[Tuple[str, str]] = set()
+        self._acquiring_locks: set[tuple[str, str]] = set()
 
         self.clock.looping_call(
             self._reap_stale_read_write_locks, _LOCK_TIMEOUT_MS / 10.0
@@ -288,7 +288,7 @@ class LockStore(SQLBaseStore):
 
     async def try_acquire_multi_read_write_lock(
         self,
-        lock_names: Collection[Tuple[str, str]],
+        lock_names: Collection[tuple[str, str]],
         write: bool,
     ) -> Optional[AsyncExitStack]:
         """Try to acquire multiple locks for the given names/keys. Will return
@@ -318,7 +318,7 @@ class LockStore(SQLBaseStore):
     def _try_acquire_multi_read_write_lock_txn(
         self,
         txn: LoggingTransaction,
-        lock_names: Collection[Tuple[str, str]],
+        lock_names: Collection[tuple[str, str]],
         write: bool,
     ) -> Collection["Lock"]:
         locks = []
@@ -497,7 +497,7 @@ class Lock:
 
     async def __aexit__(
         self,
-        _exctype: Optional[Type[BaseException]],
+        _exctype: Optional[type[BaseException]],
         _excinst: Optional[BaseException],
         _exctb: Optional[TracebackType],
     ) -> bool:
