@@ -19,7 +19,7 @@
 #
 #
 import json
-from typing import TYPE_CHECKING, Dict, Optional, Tuple, cast
+from typing import TYPE_CHECKING, Optional, cast
 
 from canonicaljson import encode_canonical_json
 
@@ -240,7 +240,7 @@ class ProfileWorkerStore(SQLBaseStore):
 
                 # Test exists first since value being None is used for both
                 # missing and a null JSON value.
-                exists, value = cast(Tuple[bool, JsonValue], txn.fetchone())
+                exists, value = cast(tuple[bool, JsonValue], txn.fetchone())
                 if not exists:
                     raise StoreError(404, "No row found")
                 return value
@@ -258,7 +258,7 @@ class ProfileWorkerStore(SQLBaseStore):
 
                 # If value_type is None, then the value did not exist.
                 value_type, value = cast(
-                    Tuple[Optional[str], JsonValue], txn.fetchone()
+                    tuple[Optional[str], JsonValue], txn.fetchone()
                 )
                 if not value_type:
                     raise StoreError(404, "No row found")
@@ -271,7 +271,7 @@ class ProfileWorkerStore(SQLBaseStore):
 
         return await self.db_pool.runInteraction("get_profile_field", get_profile_field)
 
-    async def get_profile_fields(self, user_id: UserID) -> Dict[str, str]:
+    async def get_profile_fields(self, user_id: UserID) -> dict[str, str]:
         """
         Get all custom profile fields for a user.
 
@@ -346,7 +346,7 @@ class ProfileWorkerStore(SQLBaseStore):
                 # possible due to the grammar.
                 (f'$."{new_field_name}"', user_id.localpart),
             )
-        row = cast(Tuple[Optional[int], Optional[int], Optional[int]], txn.fetchone())
+        row = cast(tuple[Optional[int], Optional[int], Optional[int]], txn.fetchone())
 
         # The values return null if the column is null.
         total_bytes = (
