@@ -24,14 +24,10 @@ from typing import (
     TYPE_CHECKING,
     Any,
     Collection,
-    Dict,
     Iterable,
-    List,
     Mapping,
     Optional,
     Sequence,
-    Set,
-    Tuple,
     cast,
 )
 
@@ -55,10 +51,10 @@ from synapse.types import (
     PersistedPosition,
     StrCollection,
 )
-from synapse.util import json_encoder
 from synapse.util.caches.descriptors import cached, cachedList
 from synapse.util.caches.stream_change_cache import StreamChangeCache
 from synapse.util.iterutils import batch_iter
+from synapse.util.json import json_encoder
 
 if TYPE_CHECKING:
     from synapse.server import HomeServer
@@ -92,14 +88,14 @@ class ReceiptInRoom:
         # matching threaded receipts.
 
         # Set of (user_id, event_id)
-        unthreaded_receipts: Set[Tuple[str, str]] = {
+        unthreaded_receipts: set[tuple[str, str]] = {
             (receipt.user_id, receipt.event_id)
             for receipt in receipts
             if receipt.thread_id is None
         }
 
         # event_id -> receipt_type -> user_id -> receipt data
-        content: Dict[str, Dict[str, Dict[str, JsonMapping]]] = {}
+        content: dict[str, dict[str, dict[str, JsonMapping]]] = {}
         for receipt in receipts:
             data = receipt.data
             if receipt.thread_id is not None:
@@ -180,7 +176,7 @@ class ReceiptsWorkerStore(SQLBaseStore):
         user_id: str,
         room_id: str,
         receipt_types: Collection[str],
-    ) -> Optional[Tuple[str, int]]:
+    ) -> Optional[tuple[str, int]]:
         """
         Fetch the event ID and stream_ordering for the latest unthreaded receipt
         in a room with one of the given receipt types.
@@ -212,11 +208,11 @@ class ReceiptsWorkerStore(SQLBaseStore):
         args.extend((user_id, room_id))
         txn.execute(sql, args)
 
-        return cast(Optional[Tuple[str, int]], txn.fetchone())
+        return cast(Optional[tuple[str, int]], txn.fetchone())
 
     async def get_receipts_for_user(
         self, user_id: str, receipt_types: Iterable[str]
-    ) -> Dict[str, str]:
+    ) -> dict[str, str]:
         """
         Fetch the event IDs for the latest receipts sent by the given user.
 
@@ -285,7 +281,7 @@ class ReceiptsWorkerStore(SQLBaseStore):
             A map of room ID to the latest receipt information.
         """
 
-        def f(txn: LoggingTransaction) -> List[Tuple[str, str, int, int]]:
+        def f(txn: LoggingTransaction) -> list[tuple[str, str, int, int]]:
             sql = (
                 "SELECT rl.room_id, rl.event_id,"
                 " e.topological_ordering, e.stream_ordering"
@@ -297,7 +293,7 @@ class ReceiptsWorkerStore(SQLBaseStore):
                 " AND receipt_type = ?"
             )
             txn.execute(sql, (user_id, receipt_type))
-            return cast(List[Tuple[str, str, int, int]], txn.fetchall())
+            return cast(list[tuple[str, str, int, int]], txn.fetchall())
 
         rows = await self.db_pool.runInteraction(
             "get_receipts_for_user_with_orderings", f
@@ -316,7 +312,7 @@ class ReceiptsWorkerStore(SQLBaseStore):
         room_ids: Iterable[str],
         to_key: MultiWriterStreamToken,
         from_key: Optional[MultiWriterStreamToken] = None,
-    ) -> List[JsonMapping]:
+    ) -> list[JsonMapping]:
         """Get receipts for multiple rooms for sending to clients.
 
         Args:
@@ -379,7 +375,7 @@ class ReceiptsWorkerStore(SQLBaseStore):
     ) -> Sequence[JsonMapping]:
         """See get_linearized_receipts_for_room"""
 
-        def f(txn: LoggingTransaction) -> List[Tuple[str, str, str, str]]:
+        def f(txn: LoggingTransaction) -> list[tuple[str, str, str, str]]:
             if from_key:
                 sql = """
                     SELECT stream_id, instance_name, receipt_type, user_id, event_id, data
@@ -466,7 +462,7 @@ class ReceiptsWorkerStore(SQLBaseStore):
 
                 txn.execute(sql + clause, [to_key.get_max_stream_pos()] + list(args))
 
-            results: Dict[str, List[ReceiptInRoom]] = {}
+            results: dict[str, list[ReceiptInRoom]] = {}
             for (
                 stream_id,
                 instance_name,
@@ -515,7 +511,7 @@ class ReceiptsWorkerStore(SQLBaseStore):
 
     async def get_linearized_receipts_for_events(
         self,
-        room_and_event_ids: Collection[Tuple[str, str]],
+        room_and_event_ids: Collection[tuple[str, str]],
     ) -> Mapping[str, Sequence[ReceiptInRoom]]:
         """Get all receipts for the given set of events.
 
@@ -531,8 +527,8 @@ class ReceiptsWorkerStore(SQLBaseStore):
 
         def get_linearized_receipts_for_events_txn(
             txn: LoggingTransaction,
-            room_id_event_id_tuples: Collection[Tuple[str, str]],
-        ) -> List[Tuple[str, str, str, str, Optional[str], str]]:
+            room_id_event_id_tuples: Collection[tuple[str, str]],
+        ) -> list[tuple[str, str, str, str, Optional[str], str]]:
             clause, args = make_tuple_in_list_sql_clause(
                 self.database_engine, ("room_id", "event_id"), room_id_event_id_tuples
             )
@@ -548,7 +544,7 @@ class ReceiptsWorkerStore(SQLBaseStore):
             return txn.fetchall()
 
         # room_id -> receipts
-        room_to_receipts: Dict[str, List[ReceiptInRoom]] = {}
+        room_to_receipts: dict[str, list[ReceiptInRoom]] = {}
         for batch in batch_iter(room_and_event_ids, 1000):
             batch_results = await self.db_pool.runInteraction(
                 "get_linearized_receipts_for_events",
@@ -596,7 +592,7 @@ class ReceiptsWorkerStore(SQLBaseStore):
             A dictionary of roomids to a list of receipts.
         """
 
-        def f(txn: LoggingTransaction) -> List[Tuple[str, str, str, str, str]]:
+        def f(txn: LoggingTransaction) -> list[tuple[str, str, str, str, str]]:
             if from_key:
                 sql = """
                     SELECT stream_id, instance_name, room_id, receipt_type, user_id, event_id, data
@@ -659,7 +655,7 @@ class ReceiptsWorkerStore(SQLBaseStore):
         def get_linearized_receipts_for_user_in_rooms_txn(
             txn: LoggingTransaction,
             batch_room_ids: StrCollection,
-        ) -> List[Tuple[str, str, str, str, Optional[str], str]]:
+        ) -> list[tuple[str, str, str, str, Optional[str], str]]:
             clause, args = make_in_list_sql_clause(
                 self.database_engine, "room_id", batch_room_ids
             )
@@ -687,7 +683,7 @@ class ReceiptsWorkerStore(SQLBaseStore):
             ]
 
         # room_id -> receipts
-        room_to_receipts: Dict[str, List[ReceiptInRoom]] = {}
+        room_to_receipts: dict[str, list[ReceiptInRoom]] = {}
         for batch in batch_iter(room_ids, 1000):
             batch_results = await self.db_pool.runInteraction(
                 "get_linearized_receipts_for_events",
@@ -746,7 +742,7 @@ class ReceiptsWorkerStore(SQLBaseStore):
 
             return [room_id for (room_id,) in txn]
 
-        results: List[str] = []
+        results: list[str] = []
         for batch in batch_iter(room_ids, 1000):
             batch_result = await self.db_pool.runInteraction(
                 "get_rooms_with_receipts_between", f, batch
@@ -757,7 +753,7 @@ class ReceiptsWorkerStore(SQLBaseStore):
 
     async def get_users_sent_receipts_between(
         self, last_id: int, current_id: int
-    ) -> List[str]:
+    ) -> list[str]:
         """Get all users who sent receipts between `last_id` exclusive and
         `current_id` inclusive.
 
@@ -768,7 +764,7 @@ class ReceiptsWorkerStore(SQLBaseStore):
         if last_id == current_id:
             return []
 
-        def _get_users_sent_receipts_between_txn(txn: LoggingTransaction) -> List[str]:
+        def _get_users_sent_receipts_between_txn(txn: LoggingTransaction) -> list[str]:
             sql = """
                 SELECT DISTINCT user_id FROM receipts_linearized
                 WHERE ? < stream_id AND stream_id <= ?
@@ -783,8 +779,8 @@ class ReceiptsWorkerStore(SQLBaseStore):
 
     async def get_all_updated_receipts(
         self, instance_name: str, last_id: int, current_id: int, limit: int
-    ) -> Tuple[
-        List[Tuple[int, Tuple[str, str, str, str, Optional[str], JsonDict]]], int, bool
+    ) -> tuple[
+        list[tuple[int, tuple[str, str, str, str, Optional[str], JsonDict]]], int, bool
     ]:
         """Get updates for receipts replication stream.
 
@@ -812,8 +808,8 @@ class ReceiptsWorkerStore(SQLBaseStore):
 
         def get_all_updated_receipts_txn(
             txn: LoggingTransaction,
-        ) -> Tuple[
-            List[Tuple[int, Tuple[str, str, str, str, Optional[str], JsonDict]]],
+        ) -> tuple[
+            list[tuple[int, tuple[str, str, str, str, Optional[str], JsonDict]]],
             int,
             bool,
         ]:
@@ -828,7 +824,7 @@ class ReceiptsWorkerStore(SQLBaseStore):
             txn.execute(sql, (last_id, current_id, instance_name, limit))
 
             updates = cast(
-                List[Tuple[int, Tuple[str, str, str, str, Optional[str], JsonDict]]],
+                list[tuple[int, tuple[str, str, str, str, Optional[str], JsonDict]]],
                 [(r[0], r[1:6] + (db_to_json(r[6]),)) for r in txn],
             )
 
@@ -917,7 +913,7 @@ class ReceiptsWorkerStore(SQLBaseStore):
         if stream_ordering is not None:
             if thread_id is None:
                 thread_clause = "r.thread_id IS NULL"
-                thread_args: Tuple[str, ...] = ()
+                thread_args: tuple[str, ...] = ()
             else:
                 thread_clause = "r.thread_id = ?"
                 thread_args = (thread_id,)
@@ -986,7 +982,7 @@ class ReceiptsWorkerStore(SQLBaseStore):
         return rx_ts
 
     def _graph_to_linear(
-        self, txn: LoggingTransaction, room_id: str, event_ids: List[str]
+        self, txn: LoggingTransaction, room_id: str, event_ids: list[str]
     ) -> str:
         """
         Generate a linearized event from a list of events (i.e. a list of forward
@@ -1026,7 +1022,7 @@ class ReceiptsWorkerStore(SQLBaseStore):
         room_id: str,
         receipt_type: str,
         user_id: str,
-        event_ids: List[str],
+        event_ids: list[str],
         thread_id: Optional[str],
         data: dict,
     ) -> Optional[PersistedPosition]:
@@ -1073,7 +1069,7 @@ class ReceiptsWorkerStore(SQLBaseStore):
         if event_ts is None:
             return None
 
-        now = self._clock.time_msec()
+        now = self.clock.time_msec()
         logger.debug(
             "Receipt %s for event %s in %s (%i ms old)",
             receipt_type,
@@ -1098,7 +1094,7 @@ class ReceiptsWorkerStore(SQLBaseStore):
         room_id: str,
         receipt_type: str,
         user_id: str,
-        event_ids: List[str],
+        event_ids: list[str],
         thread_id: Optional[str],
         data: JsonDict,
     ) -> None:
@@ -1237,7 +1233,7 @@ class ReceiptsBackgroundUpdateStore(SQLBaseStore):
                 HAVING COUNT(*) > 1
             """
             txn.execute(sql)
-            duplicate_keys = cast(List[Tuple[int, str, str, str]], list(txn))
+            duplicate_keys = cast(list[tuple[int, str, str, str]], list(txn))
 
             # Then remove duplicate receipts, keeping the one with the highest
             # `stream_id`. Since there might be duplicate rows with the same
@@ -1255,7 +1251,7 @@ class ReceiptsBackgroundUpdateStore(SQLBaseStore):
                 LIMIT 1
                 """
                 txn.execute(sql, (room_id, receipt_type, user_id, stream_id))
-                row_id = cast(Tuple[str], txn.fetchone())[0]
+                row_id = cast(tuple[str], txn.fetchone())[0]
 
                 sql = f"""
                     DELETE FROM receipts_linearized
@@ -1306,7 +1302,7 @@ class ReceiptsBackgroundUpdateStore(SQLBaseStore):
                 HAVING COUNT(*) > 1
             """
             txn.execute(sql)
-            duplicate_keys = cast(List[Tuple[str, str, str]], list(txn))
+            duplicate_keys = cast(list[tuple[str, str, str]], list(txn))
 
             # Then remove all duplicate receipts.
             # We could be clever and try to keep the latest receipt out of every set of
