@@ -47,15 +47,11 @@ from typing import (
     AbstractSet,
     Any,
     Collection,
-    Dict,
     Iterable,
-    List,
     Literal,
     Mapping,
     Optional,
     Protocol,
-    Set,
-    Tuple,
     cast,
     overload,
 )
@@ -109,7 +105,7 @@ class PaginateFunction(Protocol):
         to_key: Optional[RoomStreamToken] = None,
         direction: Direction = Direction.BACKWARDS,
         limit: int = 0,
-    ) -> Tuple[List[EventBase], RoomStreamToken, bool]: ...
+    ) -> tuple[list[EventBase], RoomStreamToken, bool]: ...
 
 
 # Used as return values for pagination APIs
@@ -122,8 +118,8 @@ class _EventDictReturn:
 
 @attr.s(slots=True, frozen=True, auto_attribs=True)
 class _EventsAround:
-    events_before: List[EventBase]
-    events_after: List[EventBase]
+    events_before: list[EventBase]
+    events_after: list[EventBase]
     start: RoomStreamToken
     end: RoomStreamToken
 
@@ -156,9 +152,9 @@ class CurrentStateDeltaMembership:
 
 def generate_pagination_where_clause(
     direction: Direction,
-    column_names: Tuple[str, str],
-    from_token: Optional[Tuple[Optional[int], int]],
-    to_token: Optional[Tuple[Optional[int], int]],
+    column_names: tuple[str, str],
+    from_token: Optional[tuple[Optional[int], int]],
+    to_token: Optional[tuple[Optional[int], int]],
     engine: BaseDatabaseEngine,
 ) -> str:
     """Creates an SQL expression to bound the columns by the pagination
@@ -224,8 +220,8 @@ def generate_pagination_bounds(
     direction: Direction,
     from_token: Optional[RoomStreamToken],
     to_token: Optional[RoomStreamToken],
-) -> Tuple[
-    str, Optional[Tuple[Optional[int], int]], Optional[Tuple[Optional[int], int]]
+) -> tuple[
+    str, Optional[tuple[Optional[int], int]], Optional[tuple[Optional[int], int]]
 ]:
     """
     Generate a start and end point for this page of events.
@@ -261,7 +257,7 @@ def generate_pagination_bounds(
     # by fetching all events between the min stream token and the maximum
     # stream token (as returned by `RoomStreamToken.get_max_stream_pos`) and
     # then filtering the results.
-    from_bound: Optional[Tuple[Optional[int], int]] = None
+    from_bound: Optional[tuple[Optional[int], int]] = None
     if from_token:
         if from_token.topological is not None:
             from_bound = from_token.as_historical_tuple()
@@ -276,7 +272,7 @@ def generate_pagination_bounds(
                 from_token.stream,
             )
 
-    to_bound: Optional[Tuple[Optional[int], int]] = None
+    to_bound: Optional[tuple[Optional[int], int]] = None
     if to_token:
         if to_token.topological is not None:
             to_bound = to_token.as_historical_tuple()
@@ -320,8 +316,8 @@ def generate_next_token(
 
 def _make_generic_sql_bound(
     bound: str,
-    column_names: Tuple[str, str],
-    values: Tuple[Optional[int], int],
+    column_names: tuple[str, str],
+    values: tuple[Optional[int], int],
     engine: BaseDatabaseEngine,
 ) -> str:
     """Create an SQL expression that bounds the given column names by the
@@ -484,7 +480,7 @@ def _filter_results_by_stream(
     return True
 
 
-def filter_to_clause(event_filter: Optional[Filter]) -> Tuple[str, List[str]]:
+def filter_to_clause(event_filter: Optional[Filter]) -> tuple[str, list[str]]:
     # NB: This may create SQL clauses that don't optimise well (and we don't
     # have indices on all possible clauses). E.g. it may create
     # "room_id == X AND room_id != X", which postgres doesn't optimise.
@@ -669,7 +665,7 @@ class StreamWorkerStore(EventsWorkerStore, SQLBaseStore):
         to_key: Optional[RoomStreamToken] = None,
         direction: Direction = Direction.BACKWARDS,
         limit: int = 0,
-    ) -> Dict[str, Tuple[List[EventBase], RoomStreamToken, bool]]:
+    ) -> dict[str, tuple[list[EventBase], RoomStreamToken, bool]]:
         """Get new room events in stream ordering since `from_key`.
 
         Args:
@@ -730,7 +726,7 @@ class StreamWorkerStore(EventsWorkerStore, SQLBaseStore):
 
     def get_rooms_that_changed(
         self, room_ids: Collection[str], from_key: RoomStreamToken
-    ) -> Set[str]:
+    ) -> set[str]:
         """Given a list of rooms and a token, return rooms where there may have
         been changes.
         """
@@ -765,7 +761,7 @@ class StreamWorkerStore(EventsWorkerStore, SQLBaseStore):
                     AND event_stream_ordering > ?
             """
 
-            results: Set[str] = set()
+            results: set[str] = set()
             for batch in batch_iter(room_ids, 1000):
                 clause, args = make_in_list_sql_clause(
                     self.database_engine, "room_id", batch
@@ -791,7 +787,7 @@ class StreamWorkerStore(EventsWorkerStore, SQLBaseStore):
         to_key: Optional[RoomStreamToken] = None,
         direction: Direction = Direction.BACKWARDS,
         limit: int = 0,
-    ) -> Tuple[List[EventBase], RoomStreamToken, bool]:
+    ) -> tuple[list[EventBase], RoomStreamToken, bool]:
         """
         Paginate events by `stream_ordering` in the room from the `from_key` in the
         given `direction` to the `to_key` or `limit`.
@@ -876,7 +872,7 @@ class StreamWorkerStore(EventsWorkerStore, SQLBaseStore):
             engine=self.database_engine,
         )
 
-        def f(txn: LoggingTransaction) -> Tuple[List[_EventDictReturn], bool]:
+        def f(txn: LoggingTransaction) -> tuple[list[_EventDictReturn], bool]:
             sql = f"""
                 SELECT event_id, instance_name, stream_ordering
                 FROM events
@@ -940,8 +936,8 @@ class StreamWorkerStore(EventsWorkerStore, SQLBaseStore):
         user_id: str,
         from_key: RoomStreamToken,
         to_key: RoomStreamToken,
-        excluded_room_ids: Optional[List[str]] = None,
-    ) -> List[CurrentStateDeltaMembership]:
+        excluded_room_ids: Optional[list[str]] = None,
+    ) -> list[CurrentStateDeltaMembership]:
         """
         Fetch membership events (and the previous event that was replaced by that one)
         for a given user.
@@ -995,13 +991,13 @@ class StreamWorkerStore(EventsWorkerStore, SQLBaseStore):
             if not has_changed:
                 return []
 
-        def f(txn: LoggingTransaction) -> List[CurrentStateDeltaMembership]:
+        def f(txn: LoggingTransaction) -> list[CurrentStateDeltaMembership]:
             # To handle tokens with a non-empty instance_map we fetch more
             # results than necessary and then filter down
             min_from_id = from_key.stream
             max_to_id = to_key.get_max_stream_pos()
 
-            args: List[Any] = [min_from_id, max_to_id, EventTypes.Member, user_id]
+            args: list[Any] = [min_from_id, max_to_id, EventTypes.Member, user_id]
 
             # TODO: It would be good to assert that the `from_token`/`to_token` is >=
             # the first row in `current_state_delta_stream` for the rooms we're
@@ -1044,7 +1040,7 @@ class StreamWorkerStore(EventsWorkerStore, SQLBaseStore):
 
             txn.execute(sql, args)
 
-            membership_changes: List[CurrentStateDeltaMembership] = []
+            membership_changes: list[CurrentStateDeltaMembership] = []
             for (
                 room_id,
                 event_id,
@@ -1136,7 +1132,7 @@ class StreamWorkerStore(EventsWorkerStore, SQLBaseStore):
         from_key: RoomStreamToken,
         to_key: RoomStreamToken,
         excluded_room_ids: Optional[AbstractSet[str]] = None,
-    ) -> Dict[str, RoomsForUserStateReset]:
+    ) -> dict[str, RoomsForUserStateReset]:
         """
         Fetch membership events that result in a meaningful membership change for a
         given user.
@@ -1185,7 +1181,7 @@ class StreamWorkerStore(EventsWorkerStore, SQLBaseStore):
         if excluded_room_ids is not None:
             room_ids_to_exclude = excluded_room_ids
 
-        def f(txn: LoggingTransaction) -> Dict[str, RoomsForUserStateReset]:
+        def f(txn: LoggingTransaction) -> dict[str, RoomsForUserStateReset]:
             # To handle tokens with a non-empty instance_map we fetch more
             # results than necessary and then filter down
             min_from_id = from_key.stream
@@ -1248,7 +1244,7 @@ class StreamWorkerStore(EventsWorkerStore, SQLBaseStore):
                 (user_id, EventTypes.Member, user_id, min_from_id, max_to_id),
             )
 
-            membership_changes: Dict[str, RoomsForUserStateReset] = {}
+            membership_changes: dict[str, RoomsForUserStateReset] = {}
             for (
                 room_id,
                 membership_event_id,
@@ -1332,8 +1328,8 @@ class StreamWorkerStore(EventsWorkerStore, SQLBaseStore):
         user_id: str,
         from_key: RoomStreamToken,
         to_key: RoomStreamToken,
-        excluded_rooms: Optional[List[str]] = None,
-    ) -> List[EventBase]:
+        excluded_rooms: Optional[list[str]] = None,
+    ) -> list[EventBase]:
         """Fetch membership events for a given user.
 
         All such events whose stream ordering `s` lies in the range
@@ -1351,13 +1347,13 @@ class StreamWorkerStore(EventsWorkerStore, SQLBaseStore):
             if not has_changed:
                 return []
 
-        def f(txn: LoggingTransaction) -> List[_EventDictReturn]:
+        def f(txn: LoggingTransaction) -> list[_EventDictReturn]:
             # To handle tokens with a non-empty instance_map we fetch more
             # results than necessary and then filter down
             min_from_id = from_key.stream
             max_to_id = to_key.get_max_stream_pos()
 
-            args: List[Any] = [user_id, min_from_id, max_to_id]
+            args: list[Any] = [user_id, min_from_id, max_to_id]
 
             ignore_room_clause = ""
             if excluded_rooms is not None and len(excluded_rooms) > 0:
@@ -1403,7 +1399,7 @@ class StreamWorkerStore(EventsWorkerStore, SQLBaseStore):
 
     async def get_recent_events_for_room(
         self, room_id: str, limit: int, end_token: RoomStreamToken
-    ) -> Tuple[List[EventBase], RoomStreamToken]:
+    ) -> tuple[list[EventBase], RoomStreamToken]:
         """Get the most recent events in the room in topological ordering.
 
         Args:
@@ -1428,7 +1424,7 @@ class StreamWorkerStore(EventsWorkerStore, SQLBaseStore):
 
     async def get_recent_event_ids_for_room(
         self, room_id: str, limit: int, end_token: RoomStreamToken
-    ) -> Tuple[List[_EventDictReturn], RoomStreamToken]:
+    ) -> tuple[list[_EventDictReturn], RoomStreamToken]:
         """Get the most recent events in the room in topological ordering.
 
         Args:
@@ -1459,7 +1455,7 @@ class StreamWorkerStore(EventsWorkerStore, SQLBaseStore):
 
     async def get_room_event_before_stream_ordering(
         self, room_id: str, stream_ordering: int
-    ) -> Optional[Tuple[int, int, str]]:
+    ) -> Optional[tuple[int, int, str]]:
         """Gets details of the first event in a room at or before a stream ordering
 
         Args:
@@ -1470,7 +1466,7 @@ class StreamWorkerStore(EventsWorkerStore, SQLBaseStore):
             A tuple of (stream ordering, topological ordering, event_id)
         """
 
-        def _f(txn: LoggingTransaction) -> Optional[Tuple[int, int, str]]:
+        def _f(txn: LoggingTransaction) -> Optional[tuple[int, int, str]]:
             sql = """
                 SELECT stream_ordering, topological_ordering, event_id
                 FROM events
@@ -1483,7 +1479,7 @@ class StreamWorkerStore(EventsWorkerStore, SQLBaseStore):
                 LIMIT 1
             """
             txn.execute(sql, (room_id, stream_ordering))
-            return cast(Optional[Tuple[int, int, str]], txn.fetchone())
+            return cast(Optional[tuple[int, int, str]], txn.fetchone())
 
         return await self.db_pool.runInteraction(
             "get_room_event_before_stream_ordering", _f
@@ -1519,7 +1515,7 @@ class StreamWorkerStore(EventsWorkerStore, SQLBaseStore):
         self,
         room_id: str,
         event_types: Optional[StrCollection] = None,
-    ) -> Optional[Tuple[str, PersistedEventPosition]]:
+    ) -> Optional[tuple[str, PersistedEventPosition]]:
         """
         Returns the ID and event position of the last event in a room.
 
@@ -1536,9 +1532,9 @@ class StreamWorkerStore(EventsWorkerStore, SQLBaseStore):
 
         def _get_last_event_pos_in_room_txn(
             txn: LoggingTransaction,
-        ) -> Optional[Tuple[str, PersistedEventPosition]]:
+        ) -> Optional[tuple[str, PersistedEventPosition]]:
             event_type_clause = ""
-            event_type_args: List[str] = []
+            event_type_args: list[str] = []
             if event_types is not None and len(event_types) > 0:
                 event_type_clause, event_type_args = make_in_list_sql_clause(
                     txn.database_engine, "type", event_types
@@ -1562,7 +1558,7 @@ class StreamWorkerStore(EventsWorkerStore, SQLBaseStore):
                 [room_id] + event_type_args,
             )
 
-            row = cast(Optional[Tuple[str, int, str]], txn.fetchone())
+            row = cast(Optional[tuple[str, int, str]], txn.fetchone())
             if row is not None:
                 event_id, stream_ordering, instance_name = row
 
@@ -1585,7 +1581,7 @@ class StreamWorkerStore(EventsWorkerStore, SQLBaseStore):
         room_id: str,
         end_token: RoomStreamToken,
         event_types: Optional[StrCollection] = None,
-    ) -> Optional[Tuple[str, PersistedEventPosition]]:
+    ) -> Optional[tuple[str, PersistedEventPosition]]:
         """
         Returns the ID and event position of the last event in a room at or before a
         stream ordering.
@@ -1602,7 +1598,7 @@ class StreamWorkerStore(EventsWorkerStore, SQLBaseStore):
 
         def get_last_event_pos_in_room_before_stream_ordering_txn(
             txn: LoggingTransaction,
-        ) -> Optional[Tuple[str, PersistedEventPosition]]:
+        ) -> Optional[tuple[str, PersistedEventPosition]]:
             # We're looking for the closest event at or before the token. We need to
             # handle the fact that the stream token can be a vector clock (with an
             # `instance_map`) and events can be persisted on different instances
@@ -1616,7 +1612,7 @@ class StreamWorkerStore(EventsWorkerStore, SQLBaseStore):
             max_stream = end_token.get_max_stream_pos()
 
             event_type_clause = ""
-            event_type_args: List[str] = []
+            event_type_args: list[str] = []
             if event_types is not None and len(event_types) > 0:
                 event_type_clause, event_type_args = make_in_list_sql_clause(
                     txn.database_engine, "type", event_types
@@ -1692,7 +1688,7 @@ class StreamWorkerStore(EventsWorkerStore, SQLBaseStore):
         self,
         room_ids: StrCollection,
         end_token: RoomStreamToken,
-    ) -> Dict[str, int]:
+    ) -> dict[str, int]:
         """Bulk fetch the stream position of the latest events in the given
         rooms
         """
@@ -1705,8 +1701,8 @@ class StreamWorkerStore(EventsWorkerStore, SQLBaseStore):
         # Check that the stream position for the rooms are from before the
         # minimum position of the token. If not then we need to fetch more
         # rows.
-        results: Dict[str, int] = {}
-        recheck_rooms: Set[str] = set()
+        results: dict[str, int] = {}
+        recheck_rooms: set[str] = set()
         min_token = end_token.stream
         for room_id, stream in uncapped_results.items():
             if stream is None:
@@ -1747,11 +1743,11 @@ class StreamWorkerStore(EventsWorkerStore, SQLBaseStore):
         now_token = self.get_room_max_token()
         max_pos = now_token.get_max_stream_pos()
 
-        results: Dict[str, int] = {}
+        results: dict[str, int] = {}
 
         # First, we check for the rooms in the stream change cache to see if we
         # can just use the latest position from it.
-        missing_room_ids: Set[str] = set()
+        missing_room_ids: set[str] = set()
         for room_id in room_ids:
             stream_pos = self._events_stream_cache.get_max_pos_of_last_change(room_id)
             if stream_pos is not None:
@@ -1770,7 +1766,7 @@ class StreamWorkerStore(EventsWorkerStore, SQLBaseStore):
 
         def bulk_get_max_event_pos_fallback_txn(
             txn: LoggingTransaction, batched_room_ids: StrCollection
-        ) -> Dict[str, int]:
+        ) -> dict[str, int]:
             clause, args = make_in_list_sql_clause(
                 self.database_engine, "room_id", batched_room_ids
             )
@@ -1795,7 +1791,7 @@ class StreamWorkerStore(EventsWorkerStore, SQLBaseStore):
         # the joins and sub-queries.
         def bulk_get_max_event_pos_from_sliding_sync_tables_txn(
             txn: LoggingTransaction, batched_room_ids: StrCollection
-        ) -> Dict[str, int]:
+        ) -> dict[str, int]:
             clause, args = make_in_list_sql_clause(
                 self.database_engine, "room_id", batched_room_ids
             )
@@ -1808,7 +1804,7 @@ class StreamWorkerStore(EventsWorkerStore, SQLBaseStore):
             txn.execute(sql, args)
             return {row[0]: row[1] for row in txn}
 
-        recheck_rooms: Set[str] = set()
+        recheck_rooms: set[str] = set()
         for batched in batch_iter(room_ids, 1000):
             if await self.have_finished_sliding_sync_background_jobs():
                 batch_results = await self.db_pool.runInteraction(
@@ -2077,7 +2073,7 @@ class StreamWorkerStore(EventsWorkerStore, SQLBaseStore):
         from_id: int,
         current_id: int,
         limit: int,
-    ) -> Tuple[int, Dict[str, Optional[int]]]:
+    ) -> tuple[int, dict[str, Optional[int]]]:
         """Get all new events
 
         Returns all event ids with from_id < stream_ordering <= current_id.
@@ -2098,7 +2094,7 @@ class StreamWorkerStore(EventsWorkerStore, SQLBaseStore):
 
         def get_all_new_event_ids_stream_txn(
             txn: LoggingTransaction,
-        ) -> Tuple[int, Dict[str, Optional[int]]]:
+        ) -> tuple[int, dict[str, Optional[int]]]:
             sql = (
                 "SELECT e.stream_ordering, e.event_id, e.received_ts"
                 " FROM events AS e"
@@ -2115,7 +2111,7 @@ class StreamWorkerStore(EventsWorkerStore, SQLBaseStore):
             if len(rows) == limit:
                 upper_bound = rows[-1][0]
 
-            event_to_received_ts: Dict[str, Optional[int]] = {
+            event_to_received_ts: dict[str, Optional[int]] = {
                 row[1]: row[2] for row in rows
             }
             return upper_bound, event_to_received_ts
@@ -2194,7 +2190,7 @@ class StreamWorkerStore(EventsWorkerStore, SQLBaseStore):
         """
         txn.execute(sql)
         min_positions = dict(
-            cast(Iterable[Tuple[str, int]], txn)
+            cast(Iterable[tuple[str, int]], txn)
         )  # Map from type -> min position
 
         # Ensure we do actually have some values here
@@ -2229,7 +2225,7 @@ class StreamWorkerStore(EventsWorkerStore, SQLBaseStore):
         direction: Direction = Direction.BACKWARDS,
         limit: int = 0,
         event_filter: Optional[Filter] = None,
-    ) -> Tuple[List[_EventDictReturn], RoomStreamToken, bool]:
+    ) -> tuple[list[_EventDictReturn], RoomStreamToken, bool]:
         """Returns list of events before or after a given token.
 
         Args:
@@ -2269,7 +2265,7 @@ class StreamWorkerStore(EventsWorkerStore, SQLBaseStore):
             # Token selection matches what we do below if there are no rows
             return [], to_token if to_token else from_token, False
 
-        args: List[Any] = [room_id]
+        args: list[Any] = [room_id]
 
         order, from_bound, to_bound = generate_pagination_bounds(
             direction, from_token, to_token
@@ -2403,7 +2399,7 @@ class StreamWorkerStore(EventsWorkerStore, SQLBaseStore):
         direction: Direction = Direction.BACKWARDS,
         limit: int = 0,
         event_filter: Optional[Filter] = None,
-    ) -> Tuple[List[EventBase], RoomStreamToken, bool]:
+    ) -> tuple[list[EventBase], RoomStreamToken, bool]:
         """
         Paginate events by `topological_ordering` (tie-break with `stream_ordering`) in
         the room from the `from_key` in the given `direction` to the `to_key` or
