@@ -26,27 +26,16 @@ from typing import (
     TYPE_CHECKING,
     Collection,
     Iterable,
-    List,
     Optional,
     Sequence,
-    Set,
-    Tuple,
     TypedDict,
     cast,
 )
 
 import attr
 
-try:
-    # Figure out if ICU support is available for searching users.
-    import icu
-
-    USE_ICU = True
-except ModuleNotFoundError:
-    # except ModuleNotFoundError:
-    USE_ICU = False
-
 from synapse.api.errors import StoreError
+from synapse.synapse_rust import segmenter as icu
 from synapse.util.stringutils import non_null_str_or_none
 
 if TYPE_CHECKING:
@@ -217,7 +206,7 @@ class UserDirectoryBackgroundUpdateStore(StateDeltasStore):
 
         def _get_next_batch(
             txn: LoggingTransaction,
-        ) -> Optional[Sequence[Tuple[str, int]]]:
+        ) -> Optional[Sequence[tuple[str, int]]]:
             # Only fetch 250 rooms, so we don't fetch too many at once, even
             # if those 250 rooms have less than batch_size state events.
             sql = """
@@ -226,7 +215,7 @@ class UserDirectoryBackgroundUpdateStore(StateDeltasStore):
                 LIMIT 250
             """ % (TEMP_TABLE + "_rooms",)
             txn.execute(sql)
-            rooms_to_work_on = cast(List[Tuple[str, int]], txn.fetchall())
+            rooms_to_work_on = cast(list[tuple[str, int]], txn.fetchall())
 
             if not rooms_to_work_on:
                 return None
@@ -364,27 +353,19 @@ class UserDirectoryBackgroundUpdateStore(StateDeltasStore):
         def _populate_user_directory_process_users_txn(
             txn: LoggingTransaction,
         ) -> Optional[int]:
-            if self.database_engine.supports_returning:
-                # Note: we use an ORDER BY in the SELECT to force usage of an
-                # index. Otherwise, postgres does a sequential scan that is
-                # surprisingly slow (I think due to the fact it will read/skip
-                # over lots of already deleted rows).
-                sql = f"""
-                    DELETE FROM {TEMP_TABLE + "_users"}
-                    WHERE user_id IN (
-                        SELECT user_id FROM {TEMP_TABLE + "_users"} ORDER BY user_id LIMIT ?
-                    )
-                    RETURNING user_id
-                """
-                txn.execute(sql, (batch_size,))
-                user_result = cast(List[Tuple[str]], txn.fetchall())
-            else:
-                sql = "SELECT user_id FROM %s ORDER BY user_id LIMIT %s" % (
-                    TEMP_TABLE + "_users",
-                    str(batch_size),
+            # Note: we use an ORDER BY in the SELECT to force usage of an
+            # index. Otherwise, postgres does a sequential scan that is
+            # surprisingly slow (I think due to the fact it will read/skip
+            # over lots of already deleted rows).
+            sql = f"""
+                DELETE FROM {TEMP_TABLE + "_users"}
+                WHERE user_id IN (
+                    SELECT user_id FROM {TEMP_TABLE + "_users"} ORDER BY user_id LIMIT ?
                 )
-                txn.execute(sql)
-                user_result = cast(List[Tuple[str]], txn.fetchall())
+                RETURNING user_id
+            """
+            txn.execute(sql, (batch_size,))
+            user_result = cast(list[tuple[str]], txn.fetchall())
 
             if not user_result:
                 return None
@@ -416,7 +397,7 @@ class UserDirectoryBackgroundUpdateStore(StateDeltasStore):
 
             # Next fetch their profiles. Note that not all users have profiles.
             profile_rows = cast(
-                List[Tuple[str, Optional[str], Optional[str]]],
+                list[tuple[str, Optional[str], Optional[str]]],
                 self.db_pool.simple_select_many_txn(
                     txn,
                     table="profiles",
@@ -443,17 +424,6 @@ class UserDirectoryBackgroundUpdateStore(StateDeltasStore):
             # Actually insert the users with their profiles into the directory.
             self._update_profiles_in_user_dir_txn(txn, profiles_to_insert)
 
-            # We've finished processing the users. Delete it from the table, if
-            # we haven't already.
-            if not self.database_engine.supports_returning:
-                self.db_pool.simple_delete_many_txn(
-                    txn,
-                    table=TEMP_TABLE + "_users",
-                    column="user_id",
-                    values=users_to_work_on,
-                    keyvalues={},
-                )
-
             # Update the remaining counter.
             progress["remaining"] -= len(users_to_work_on)
             self.db_pool.updates._background_update_progress_txn(
@@ -522,7 +492,7 @@ class UserDirectoryBackgroundUpdateStore(StateDeltasStore):
         ]
 
         rows = cast(
-            List[Tuple[str, Optional[str]]],
+            list[tuple[str, Optional[str]]],
             self.db_pool.simple_select_many_txn(
                 txn,
                 table="users",
@@ -616,7 +586,7 @@ class UserDirectoryBackgroundUpdateStore(StateDeltasStore):
 
     async def get_remote_servers_with_profiles_to_refresh(
         self, now_ts: int, limit: int
-    ) -> List[str]:
+    ) -> list[str]:
         """
         Get a list of up to `limit` server names which have users whose
         locally-cached profiles we believe to be stale
@@ -625,7 +595,7 @@ class UserDirectoryBackgroundUpdateStore(StateDeltasStore):
 
         def _get_remote_servers_with_refreshable_profiles_txn(
             txn: LoggingTransaction,
-        ) -> List[str]:
+        ) -> list[str]:
             sql = """
                 SELECT user_server_name
                 FROM user_directory_stale_remote_users
@@ -644,7 +614,7 @@ class UserDirectoryBackgroundUpdateStore(StateDeltasStore):
 
     async def get_remote_users_to_refresh_on_server(
         self, server_name: str, now_ts: int, limit: int
-    ) -> List[Tuple[str, int, int]]:
+    ) -> list[tuple[str, int, int]]:
         """
         Get a list of up to `limit` user IDs from the server `server_name`
         whose locally-cached profiles we believe to be stale
@@ -659,7 +629,7 @@ class UserDirectoryBackgroundUpdateStore(StateDeltasStore):
 
         def _get_remote_users_to_refresh_on_server_txn(
             txn: LoggingTransaction,
-        ) -> List[Tuple[str, int, int]]:
+        ) -> list[tuple[str, int, int]]:
             sql = """
                 SELECT user_id, retry_counter, next_try_at_ts
                 FROM user_directory_stale_remote_users
@@ -668,7 +638,7 @@ class UserDirectoryBackgroundUpdateStore(StateDeltasStore):
                 LIMIT ?
             """
             txn.execute(sql, (server_name, now_ts, limit))
-            return cast(List[Tuple[str, int, int]], txn.fetchall())
+            return cast(list[tuple[str, int, int]], txn.fetchall())
 
         return await self.db_pool.runInteraction(
             "get_remote_users_to_refresh_on_server",
@@ -779,7 +749,7 @@ class UserDirectoryBackgroundUpdateStore(StateDeltasStore):
             raise Exception("Unrecognized database engine")
 
     async def add_users_who_share_private_room(
-        self, room_id: str, user_id_tuples: Iterable[Tuple[str, str]]
+        self, room_id: str, user_id_tuples: Iterable[tuple[str, str]]
     ) -> None:
         """Insert entries into the users_who_share_private_rooms table. The first
         user should be a local user.
@@ -842,7 +812,7 @@ class UserDirectoryBackgroundUpdateStore(StateDeltasStore):
 
     async def _get_user_in_directory(
         self, user_id: str
-    ) -> Optional[Tuple[Optional[str], Optional[str]]]:
+    ) -> Optional[tuple[Optional[str], Optional[str]]]:
         """
         Fetch the user information in the user directory.
 
@@ -851,7 +821,7 @@ class UserDirectoryBackgroundUpdateStore(StateDeltasStore):
             avatar URL (both of which may be None).
         """
         return cast(
-            Optional[Tuple[Optional[str], Optional[str]]],
+            Optional[tuple[Optional[str], Optional[str]]],
             await self.db_pool.simple_select_one(
                 table="user_directory",
                 keyvalues={"user_id": user_id},
@@ -872,7 +842,7 @@ class UserDirectoryBackgroundUpdateStore(StateDeltasStore):
 
 class SearchResult(TypedDict):
     limited: bool
-    results: List[UserProfile]
+    results: list[UserProfile]
 
 
 class UserDirectoryStore(UserDirectoryBackgroundUpdateStore):
@@ -919,7 +889,7 @@ class UserDirectoryStore(UserDirectoryBackgroundUpdateStore):
             "remove_from_user_dir", _remove_from_user_dir_txn
         )
 
-    async def get_users_in_dir_due_to_room(self, room_id: str) -> Set[str]:
+    async def get_users_in_dir_due_to_room(self, room_id: str) -> set[str]:
         """Get all user_ids that are in the room directory because they're
         in the given room_id
         """
@@ -973,7 +943,7 @@ class UserDirectoryStore(UserDirectoryBackgroundUpdateStore):
             "remove_user_who_share_room", _remove_user_who_share_room_txn
         )
 
-    async def get_user_dir_rooms_user_is_in(self, user_id: str) -> List[str]:
+    async def get_user_dir_rooms_user_is_in(self, user_id: str) -> list[str]:
         """
         Returns the rooms that a user is in.
 
@@ -1039,7 +1009,7 @@ class UserDirectoryStore(UserDirectoryBackgroundUpdateStore):
                 }
         """
 
-        join_args: Tuple[str, ...] = (user_id,)
+        join_args: tuple[str, ...] = (user_id,)
 
         if self.hs.config.userdirectory.user_directory_search_all_users:
             where_clause = "user_id != ?"
@@ -1068,7 +1038,7 @@ class UserDirectoryStore(UserDirectoryBackgroundUpdateStore):
         # We allow manipulating the ranking algorithm by injecting statements
         # based on config options.
         additional_ordering_statements = []
-        ordering_arguments: Tuple[str, ...] = ()
+        ordering_arguments: tuple[str, ...] = ()
 
         if isinstance(self.database_engine, PostgresEngine):
             full_query, exact_query, prefix_query = _parse_query_postgres(search_term)
@@ -1174,7 +1144,7 @@ class UserDirectoryStore(UserDirectoryBackgroundUpdateStore):
             raise Exception("Unrecognized database engine")
 
         results = cast(
-            List[Tuple[str, Optional[str], Optional[str]]],
+            list[tuple[str, Optional[str], Optional[str]]],
             await self.db_pool.execute("search_user_dir", sql, *args),
         )
 
@@ -1226,7 +1196,7 @@ def _filter_text_for_index(text: str) -> str:
 
 def _parse_query_sqlite(search_term: str) -> str:
     """Takes a plain unicode string from the user and converts it into a form
-    that can be passed to database.
+    that can be passed to the database.
     We use this so that we can add prefix matching, which isn't something
     that is supported by default.
 
@@ -1240,9 +1210,9 @@ def _parse_query_sqlite(search_term: str) -> str:
     return " & ".join("(%s* OR %s)" % (result, result) for result in results)
 
 
-def _parse_query_postgres(search_term: str) -> Tuple[str, str, str]:
+def _parse_query_postgres(search_term: str) -> tuple[str, str, str]:
     """Takes a plain unicode string from the user and converts it into a form
-    that can be passed to database.
+    that can be passed to the database.
     We use this so that we can add prefix matching, which isn't something
     that is supported by default.
     """
@@ -1271,13 +1241,8 @@ def _parse_query_postgres(search_term: str) -> Tuple[str, str, str]:
     return both, exact, prefix
 
 
-def _parse_words(search_term: str) -> List[str]:
-    """Split the provided search string into a list of its words.
-
-    If support for ICU (International Components for Unicode) is available, use it.
-    Otherwise, fall back to using a regex to detect word boundaries. This latter
-    solution works well enough for most latin-based languages, but doesn't work as well
-    with other languages.
+def _parse_words(search_term: str) -> list[str]:
+    """Split the provided search string into a list of its words using ICU.
 
     Args:
         search_term: The search string.
@@ -1285,21 +1250,10 @@ def _parse_words(search_term: str) -> List[str]:
     Returns:
         A list of the words in the search string.
     """
-    if USE_ICU:
-        return _parse_words_with_icu(search_term)
-
-    return _parse_words_with_regex(search_term)
+    return _parse_words_with_icu(search_term)
 
 
-def _parse_words_with_regex(search_term: str) -> List[str]:
-    """
-    Break down search term into words, when we don't have ICU available.
-    See: `_parse_words`
-    """
-    return re.findall(r"([\w-]+)", search_term, re.UNICODE)
-
-
-def _parse_words_with_icu(search_term: str) -> List[str]:
+def _parse_words_with_icu(search_term: str) -> list[str]:
     """Break down the provided search string into its individual words using ICU
     (International Components for Unicode).
 
@@ -1310,28 +1264,19 @@ def _parse_words_with_icu(search_term: str) -> List[str]:
         A list of the words in the search string.
     """
     results = []
-    breaker = icu.BreakIterator.createWordInstance(icu.Locale.getDefault())
-    breaker.setText(search_term)
-    i = 0
-    while True:
-        j = breaker.nextBoundary()
-        if j < 0:
-            break
-
+    for part in icu.parse_words(search_term):
         # We want to make sure that we split on `@` and `:` specifically, as
         # they occur in user IDs.
-        for result in re.split(r"[@:]+", search_term[i:j]):
+        for result in re.split(r"[@:]+", part):
             results.append(result.strip())
 
-        i = j
-
-    # libicu will break up words that have punctuation in them, but to handle
+    # icu will break up words that have punctuation in them, but to handle
     # cases where user IDs have '-', '.' and '_' in them we want to *not* break
     # those into words and instead allow the DB to tokenise them how it wants.
     #
     # In particular, user-71 in postgres gets tokenised to "user, -71", and this
     # will not match a query for "user, 71".
-    new_results: List[str] = []
+    new_results: list[str] = []
     i = 0
     while i < len(results):
         curr = results[i]
