@@ -1,4 +1,4 @@
-from typing import Callable, Collection, List, Optional, Tuple
+from typing import Callable, Collection, Optional
 from unittest import mock
 from unittest.mock import AsyncMock, Mock
 
@@ -55,8 +55,8 @@ class FederationCatchUpTestCases(FederatingHomeserverTestCase):
         )
 
         # whenever send_transaction is called, record the pdu data
-        self.pdus: List[JsonDict] = []
-        self.failed_pdus: List[JsonDict] = []
+        self.pdus: list[JsonDict] = []
+        self.failed_pdus: list[JsonDict] = []
         self.is_online = True
         self.federation_transport_client.send_transaction.side_effect = (
             self.record_transaction
@@ -269,7 +269,7 @@ class FederationCatchUpTestCases(FederatingHomeserverTestCase):
 
     def make_fake_destination_queue(
         self, destination: str = "host2"
-    ) -> Tuple[PerDestinationQueue, List[EventBase]]:
+    ) -> tuple[PerDestinationQueue, list[EventBase]]:
         """
         Makes a fake per-destination queue.
         """
@@ -279,8 +279,8 @@ class FederationCatchUpTestCases(FederatingHomeserverTestCase):
 
         async def fake_send(
             destination_tm: str,
-            pending_pdus: List[EventBase],
-            _pending_edus: List[Edu],
+            pending_pdus: list[EventBase],
+            _pending_edus: list[Edu],
         ) -> None:
             assert destination == destination_tm
             results_list.extend(pending_pdus)
