@@ -25,11 +25,8 @@ from typing import (
     BinaryIO,
     Callable,
     Collection,
-    Dict,
-    List,
     Literal,
     Optional,
-    Tuple,
     Union,
 )
 from unittest.mock import Mock
@@ -146,11 +143,11 @@ class TestSpamChecker:
         user_id: str,
         device_id: Optional[str],
         initial_display_name: Optional[str],
-        request_info: Collection[Tuple[Optional[str], str]],
+        request_info: Collection[tuple[Optional[str], str]],
         auth_provider_id: Optional[str] = None,
     ) -> Union[
         Literal["NOT_SPAM"],
-        Tuple["synapse.module_api.errors.Codes", JsonDict],
+        tuple["synapse.module_api.errors.Codes", JsonDict],
     ]:
         return "NOT_SPAM"
 
@@ -170,11 +167,11 @@ class DenyAllSpamChecker:
         user_id: str,
         device_id: Optional[str],
         initial_display_name: Optional[str],
-        request_info: Collection[Tuple[Optional[str], str]],
+        request_info: Collection[tuple[Optional[str], str]],
         auth_provider_id: Optional[str] = None,
     ) -> Union[
         Literal["NOT_SPAM"],
-        Tuple["synapse.module_api.errors.Codes", JsonDict],
+        tuple["synapse.module_api.errors.Codes", JsonDict],
     ]:
         # Return an odd set of values to ensure that they get correctly passed
         # to the client.
@@ -633,7 +630,7 @@ class MultiSSOTestCase(unittest.HomeserverTestCase):
         login.register_servlets,
     ]
 
-    def default_config(self) -> Dict[str, Any]:
+    def default_config(self) -> dict[str, Any]:
         config = super().default_config()
 
         config["public_baseurl"] = PUBLIC_BASEURL
@@ -678,7 +675,7 @@ class MultiSSOTestCase(unittest.HomeserverTestCase):
     def prepare(self, reactor: MemoryReactor, clock: Clock, hs: HomeServer) -> None:
         self.login_sso_redirect_url_builder = LoginSSORedirectURIBuilder(hs.config)
 
-    def create_resource_dict(self) -> Dict[str, Resource]:
+    def create_resource_dict(self) -> dict[str, Resource]:
         d = super().create_resource_dict()
         d.update(build_synapse_client_resource_tree(self.hs))
         return d
@@ -730,7 +727,7 @@ class MultiSSOTestCase(unittest.HomeserverTestCase):
         p.close()
 
         # there should be a link for each href
-        returned_idps: List[str] = []
+        returned_idps: list[str] = []
         for link in p.links:
             path, query = link.split("?", 1)
             self.assertEqual(path, "pick_idp")
@@ -891,7 +888,7 @@ class MultiSSOTestCase(unittest.HomeserverTestCase):
         # ... and should have set a cookie including the redirect url
         cookie_headers = channel.headers.getRawHeaders("Set-Cookie")
         assert cookie_headers
-        cookies: Dict[str, str] = {}
+        cookies: dict[str, str] = {}
         for h in cookie_headers:
             key, value = h.split(";")[0].split("=", maxsplit=1)
             cookies[key] = value
@@ -1179,7 +1176,7 @@ class JWTTestCase(unittest.HomeserverTestCase):
         "algorithm": jwt_algorithm,
     }
 
-    def default_config(self) -> Dict[str, Any]:
+    def default_config(self) -> dict[str, Any]:
         config = super().default_config()
 
         # If jwt_config has been defined (eg via @override_config), don't replace it.
@@ -1188,7 +1185,7 @@ class JWTTestCase(unittest.HomeserverTestCase):
 
         return config
 
-    def jwt_encode(self, payload: Dict[str, Any], secret: str = jwt_secret) -> str:
+    def jwt_encode(self, payload: dict[str, Any], secret: str = jwt_secret) -> str:
         header = {"alg": self.jwt_algorithm}
         result: bytes = jwt.encode(header, payload, secret)
         return result.decode("ascii")
@@ -1426,7 +1423,7 @@ class JWTPubKeyTestCase(unittest.HomeserverTestCase):
         ]
     )
 
-    def default_config(self) -> Dict[str, Any]:
+    def default_config(self) -> dict[str, Any]:
         config = super().default_config()
         config["jwt_config"] = {
             "enabled": True,
@@ -1435,7 +1432,7 @@ class JWTPubKeyTestCase(unittest.HomeserverTestCase):
         }
         return config
 
-    def jwt_encode(self, payload: Dict[str, Any], secret: str = jwt_privatekey) -> str:
+    def jwt_encode(self, payload: dict[str, Any], secret: str = jwt_privatekey) -> str:
         header = {"alg": "RS256"}
         if secret.startswith("-----BEGIN RSA PRIVATE KEY-----"):
             secret = JsonWebKey.import_key(secret, {"kty": "RSA"})
@@ -1630,7 +1627,7 @@ class UsernamePickerTestCase(HomeserverTestCase):
         )
         return hs
 
-    def default_config(self) -> Dict[str, Any]:
+    def default_config(self) -> dict[str, Any]:
         config = super().default_config()
         config["public_baseurl"] = PUBLIC_BASEURL
 
@@ -1649,7 +1646,7 @@ class UsernamePickerTestCase(HomeserverTestCase):
         config["sso"] = {"client_whitelist": ["https://x"]}
         return config
 
-    def create_resource_dict(self) -> Dict[str, Resource]:
+    def create_resource_dict(self) -> dict[str, Resource]:
         d = super().create_resource_dict()
         d.update(build_synapse_client_resource_tree(self.hs))
         return d
@@ -1660,7 +1657,7 @@ class UsernamePickerTestCase(HomeserverTestCase):
         displayname: str,
         email: str,
         picture: str,
-    ) -> Tuple[str, str]:
+    ) -> tuple[str, str]:
         # do the start of the login flow
         channel, _ = self.helper.auth_via_oidc(
             fake_oidc_server,
@@ -1681,7 +1678,7 @@ class UsernamePickerTestCase(HomeserverTestCase):
         self.assertEqual(picker_url, "/_synapse/client/pick_username/account_details")
 
         # ... with a username_mapping_session cookie
-        cookies: Dict[str, str] = {}
+        cookies: dict[str, str] = {}
         channel.extract_cookies(cookies)
         self.assertIn("username_mapping_session", cookies)
         session_id = cookies["username_mapping_session"]
@@ -1894,5 +1891,5 @@ async def mock_get_file(
     max_size: Optional[int] = None,
     headers: Optional[RawHeaders] = None,
     is_allowed_content_type: Optional[Callable[[str], bool]] = None,
-) -> Tuple[int, Dict[bytes, List[bytes]], str, int]:
+) -> tuple[int, dict[bytes, list[bytes]], str, int]:
     return 0, {b"Content-Type": [b"image/png"]}, "", 200
