@@ -21,14 +21,10 @@
 from typing import (
     Any,
     Collection,
-    Dict,
     Generator,
     Iterable,
     Iterator,
-    List,
     Optional,
-    Set,
-    Tuple,
 )
 from unittest.mock import AsyncMock, Mock
 
@@ -57,7 +53,7 @@ def create_event(
     state_key: Optional[str] = None,
     depth: int = 2,
     event_id: Optional[str] = None,
-    prev_events: Optional[List[Tuple[str, dict]]] = None,
+    prev_events: Optional[list[tuple[str, dict]]] = None,
     **kwargs: Any,
 ) -> EventBase:
     global _next_event_id
@@ -91,16 +87,16 @@ def create_event(
 
 class _DummyStore:
     def __init__(self) -> None:
-        self._event_to_state_group: Dict[str, int] = {}
-        self._group_to_state: Dict[int, MutableStateMap[str]] = {}
+        self._event_to_state_group: dict[str, int] = {}
+        self._group_to_state: dict[int, MutableStateMap[str]] = {}
 
-        self._event_id_to_event: Dict[str, EventBase] = {}
+        self._event_id_to_event: dict[str, EventBase] = {}
 
         self._next_group = 1
 
     async def get_state_groups_ids(
         self, room_id: str, event_ids: Collection[str]
-    ) -> Dict[int, MutableStateMap[str]]:
+    ) -> dict[int, MutableStateMap[str]]:
         groups = {}
         for event_id in event_ids:
             group = self._event_to_state_group.get(event_id)
@@ -137,7 +133,7 @@ class _DummyStore:
 
     async def get_events(
         self, event_ids: Collection[str], **kwargs: Any
-    ) -> Dict[str, EventBase]:
+    ) -> dict[str, EventBase]:
         return {
             e_id: self._event_id_to_event[e_id]
             for e_id in event_ids
@@ -146,12 +142,12 @@ class _DummyStore:
 
     async def get_partial_state_events(
         self, event_ids: Collection[str]
-    ) -> Dict[str, bool]:
+    ) -> dict[str, bool]:
         return dict.fromkeys(event_ids, False)
 
     async def get_state_group_delta(
         self, name: str
-    ) -> Tuple[Optional[int], Optional[StateMap[str]]]:
+    ) -> tuple[Optional[int], Optional[StateMap[str]]]:
         return None, None
 
     def register_events(self, events: Iterable[EventBase]) -> None:
@@ -170,7 +166,7 @@ class _DummyStore:
 
     async def get_state_group_for_events(
         self, event_ids: Collection[str], await_full_state: bool = True
-    ) -> Dict[str, int]:
+    ) -> dict[str, int]:
         res = {}
         for event in event_ids:
             res[event] = self._event_to_state_group[event]
@@ -178,7 +174,7 @@ class _DummyStore:
 
     async def get_state_for_groups(
         self, groups: Collection[int]
-    ) -> Dict[int, MutableStateMap[str]]:
+    ) -> dict[int, MutableStateMap[str]]:
         res = {}
         for group in groups:
             state = self._group_to_state[group]
@@ -193,15 +189,15 @@ class DictObj(dict):
 
 
 class Graph:
-    def __init__(self, nodes: Dict[str, DictObj], edges: Dict[str, List[str]]):
-        events: Dict[str, EventBase] = {}
-        clobbered: Set[str] = set()
+    def __init__(self, nodes: dict[str, DictObj], edges: dict[str, list[str]]):
+        events: dict[str, EventBase] = {}
+        clobbered: set[str] = set()
 
         for event_id, fields in nodes.items():
             refs = edges.get(event_id)
             if refs:
                 clobbered.difference_update(refs)
-                prev_events: List[Tuple[str, dict]] = [(r, {}) for r in refs]
+                prev_events: list[tuple[str, dict]] = [(r, {}) for r in refs]
             else:
                 prev_events = []
 
@@ -281,7 +277,7 @@ class StateTestCase(unittest.TestCase):
 
         self.dummy_store.register_events(graph.walk())
 
-        context_store: Dict[str, EventContext] = {}
+        context_store: dict[str, EventContext] = {}
 
         for event in graph.walk():
             context = yield defer.ensureDeferred(
@@ -328,7 +324,7 @@ class StateTestCase(unittest.TestCase):
 
         self.dummy_store.register_events(graph.walk())
 
-        context_store: Dict[str, EventContext] = {}
+        context_store: dict[str, EventContext] = {}
 
         for event in graph.walk():
             context = yield defer.ensureDeferred(
@@ -389,7 +385,7 @@ class StateTestCase(unittest.TestCase):
 
         self.dummy_store.register_events(graph.walk())
 
-        context_store: Dict[str, EventContext] = {}
+        context_store: dict[str, EventContext] = {}
 
         for event in graph.walk():
             context = yield defer.ensureDeferred(
@@ -467,7 +463,7 @@ class StateTestCase(unittest.TestCase):
 
         self.dummy_store.register_events(graph.walk())
 
-        context_store: Dict[str, EventContext] = {}
+        context_store: dict[str, EventContext] = {}
 
         for event in graph.walk():
             context = yield defer.ensureDeferred(
@@ -490,7 +486,7 @@ class StateTestCase(unittest.TestCase):
         self.assertEqual(ctx_d.state_group_before_event, ctx_d.state_group)
 
     def _add_depths(
-        self, nodes: Dict[str, DictObj], edges: Dict[str, List[str]]
+        self, nodes: dict[str, DictObj], edges: dict[str, list[str]]
     ) -> None:
         def _get_depth(ev: str) -> int:
             node = nodes[ev]
