@@ -23,12 +23,9 @@ from typing import (
     Any,
     Generator,
     Iterable,
-    List,
     Mapping,
     NoReturn,
     Optional,
-    Set,
-    Tuple,
     cast,
 )
 from unittest import mock
@@ -257,7 +254,7 @@ class DescriptorTestCase(unittest.TestCase):
                 return self.result
 
         obj = Cls()
-        callbacks: Set[str] = set()
+        callbacks: set[str] = set()
 
         # set off an asynchronous request
         origin_d: Deferred = Deferred()
@@ -435,7 +432,7 @@ class DescriptorTestCase(unittest.TestCase):
                 _, self.clock = get_clock()  # nb must be called this for @cached
 
             @descriptors.cached(iterable=True)
-            def fn(self, arg1: int, arg2: int) -> Tuple[str, ...]:
+            def fn(self, arg1: int, arg2: int) -> tuple[str, ...]:
                 return self.mock(arg1, arg2)
 
         obj = Cls()
@@ -925,7 +922,7 @@ class CachedListDescriptorTestCase(unittest.TestCase):
                 pass
 
             @descriptors.cachedList(cached_method_name="fn", list_name="args1")
-            def list_fn(self, args1: List[int]) -> "Deferred[Mapping[int, str]]":
+            def list_fn(self, args1: list[int]) -> "Deferred[Mapping[int, str]]":
                 return self.mock(args1)
 
         obj = Cls()
@@ -970,7 +967,7 @@ class CachedListDescriptorTestCase(unittest.TestCase):
                 pass
 
             @descriptors.cachedList(cached_method_name="fn", list_name="args1")
-            async def list_fn(self, args1: List[int], arg2: int) -> Mapping[int, str]:
+            async def list_fn(self, args1: list[int], arg2: int) -> Mapping[int, str]:
                 # we want this to behave like an asynchronous function
                 await run_on_reactor()
                 return self.mock(args1, arg2)
@@ -1012,7 +1009,7 @@ class CachedListDescriptorTestCase(unittest.TestCase):
                 pass
 
             @cachedList(cached_method_name="fn", list_name="args")
-            async def list_fn(self, args: List[int]) -> Mapping[int, str]:
+            async def list_fn(self, args: list[int]) -> Mapping[int, str]:
                 await complete_lookup
                 return {arg: str(arg) for arg in args}
 
@@ -1049,7 +1046,7 @@ class CachedListDescriptorTestCase(unittest.TestCase):
                 pass
 
             @cachedList(cached_method_name="fn", list_name="args")
-            async def list_fn(self, args: List[int]) -> Mapping[int, str]:
+            async def list_fn(self, args: list[int]) -> Mapping[int, str]:
                 await make_deferred_yieldable(complete_lookup)
                 self.inner_context_was_finished = current_context().finished
                 return {arg: str(arg) for arg in args}
@@ -1097,7 +1094,7 @@ class CachedListDescriptorTestCase(unittest.TestCase):
             # of arguments as the underlying cached function, just with one of
             # the arguments being an iterable
             @descriptors.cachedList(cached_method_name="fn", list_name="keys")
-            def list_fn(self, keys: Iterable[Tuple[str, str]]) -> None:
+            def list_fn(self, keys: Iterable[tuple[str, str]]) -> None:
                 pass
 
             # Corrected syntax ✅
